pub enum WebSocketMessage {
Text(String),
Binary(Vec<u8>),
Close {
code: u16,
reason: Option<String>,
},
Ping(Vec<u8>),
Pong(Vec<u8>),
}Expand description
A WebSocket message that can be text or binary.
Variants
Text(String)
A text message.
Binary(Vec<u8>)
A binary message.
Close
A close message with a numeric close code (RFC 6455) and optional reason text.
Common codes: 1000 Normal Closure, 1001 Going Away, 1005 No Status Received, 1006 Abnormal Closure.
Ping(Vec<u8>)
A ping message.
Pong(Vec<u8>)
A pong message.
Implementations
Sourceimpl WebSocketMessage
impl WebSocketMessage
Sourcepub fn as_json(&self) -> Result<Value, String>
pub fn as_json(&self) -> Result<Value, String>
Get the message as JSON, if it’s a text message containing JSON.
Sourcepub fn close_code(&self) -> Option<u16>
pub fn close_code(&self) -> Option<u16>
Return the close code if this is a close message.
Sourcepub fn close_reason(&self) -> Option<&str>
pub fn close_reason(&self) -> Option<&str>
Return the close reason if this is a close message with a reason.